TestFramesSpecialTargets

This test reproduces bug SEL-272

_top

TestFramesSpecialTargets
openWindow | ../tests/html/Frames.html | SpecialTargets
waitForPopUp | SpecialTargets | 10000
selectWindow | SpecialTargets |
selectFrame | bottomFrame |
clickAndWait | changeTop |
click | changeSpan |

_parent

open | ../tests/html/Frames.html |
selectFrame | bottomFrame |
clickAndWait | changeParent |
click | changeSpan |
close |  |